@@ -1,25 +1,30 @@
 from ..utils import *
+
 # from utils import *
 import html
 
 from .. import regex as re_
+
 # import regex as re_
 
 from ..data.ingredient_funnel import dictionary as ing_funnel
+
 # from data.ingredient_funnel import dictionary as ing_funnel
 from ..data.categories import models
+
 # from data.categories import models
 import numpy as np
 import unicodedata
 from unidecode import unidecode
 
 from ..data.categories import title_map, root_map, ing_keys, ing_map, exceptions
+
 # from data.categories import title_map, root_map, ing_keys, ing_map, exceptions
 import spacy
 import os
 
-ROOT_DIR = os.path.realpath(os.path.join(os.path.dirname(__file__), '..'))
-en_core_web_sm = os.path.join(ROOT_DIR, 'models', 'en_core_web_sm')
+ROOT_DIR = os.path.realpath(os.path.join(os.path.dirname(__file__), ".."))
+en_core_web_sm = os.path.join(ROOT_DIR, "models", "en_core_web_sm")
 nlp = spacy.load(en_core_web_sm)
 
 
@@ -158,7 +163,7 @@ class RecipeReader:
                 if category in categories_b:
                     out.append(model)
 
-        return out
+        return out if len(out) > 0 else ["other"]
 
     def read(self, title, phrases, steps):
         ingredients = [self.read_phrase(p) for p in phrases]
